| ahp.error | R Documentation |
Consider the comparison matrix where element a_{ij} contains the pairwise comparison between the attributes i and j. The weights of the matrix was constructed as in agg.indpref using the Perron eigenvector where p_{i} and p_{j} are the weights of the i^{th} and the j^{th} element respectively. ahp.error constructs a matrix \epsilon_{ij} = a_{ij}p_{j}/p_{i}.
ahp.error(ahpmat, atts, reciprocal = FALSE)
ahpmat |
A list of pairwise comparison matrices of each decision maker generated by |
atts |
a list of attributes in the correct order |
reciprocal |
whether to remove all numbers lower than 1 and put all numbers above 1 in the upper triangular matrix. Useful for visualizing the inconsistency rapidly. |
A list of matrices containing \epsilon_{ij} = a_{ij}p_{j}/p_{i} for each decision-maker, with elements from the lower triangle set as NA automatically (since it is essentially equal to the element in the upper triangle).
Frankie Cho
Saaty2004ahpsurvey
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
data(city200)
cityahp <- ahp.mat(city200, atts, negconvert = TRUE)
ahp.error(cityahp, atts)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.