Deprecated in version 0.4.2. Use ahp.md instead, which contains exactly the same functionality but with the correct name of the algorithm.
ahp.harker(
ahpmat,
atts,
round = FALSE,
limit = FALSE,
iterations = 1,
stopcr = 0,
printiter = TRUE
)A list of matrices with values replaced with consistent values.
A list of pairwise comparison matrices of each decision maker generated by ahp.mat.
A list of attributes in the correct order
Rounds the imputation values of the matrix to the nearest integer if TRUE. Defaults to FALSE.
If set to TRUE, if the imputation value is larger than 9 or smaller than 1/9, the value is converted to 9 and 1/9 respectively. Defaults to FALSE.
The number of comparisons with the highest inconsistency to be changed. For example, if iterations = 3, ahp.harker changes the first, second, and third most inconsistent pairwise comparisons using that method. Defaults to 1.
The stopping Consistency Ratio, which was calculated by ahp.cr. Complements iter by giving iterations a criteria to stop when a matrix is sufficiently consistent. The function will continue looping and replacing more elements of the pairwise comparison matrices until the consistency ratio of the new matrix is lower than stopcr, or the maximum number of iterations is reached, and will stop and move onto the next individual. When stopcr is set, the number of replaced elements will differ among each decision-maker. Defaults to 0 (i.e. the loop will not be stopped unless iterations is reached)
Whether the number of iterations taken for each pairwise matrix is reported or not. If printiter = TRUE, it prints out the final number of iterations that each individual decision-maker took to reach a value lower than stopcr. Generally it is not needed if stopcr is not specified. When stopcr is specified, this is a good way of identifying how many pairwise comparisons are actually replaced by the algorithm for each decision maker. Defaults to TRUE.
Frankie Cho
ahp.error ahp.cr
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
data(city200)
cityahp <- ahp.mat(city200, atts, negconvert = TRUE)
ahp.md(cityahp, atts)
Run the code above in your browser using DataLab