| ahp.mat | R Documentation |
ahp.mat takes in paired comparisons from survey data with questions using the
analytic hierarchy process and converts it into pairwise comparison matrices
for each individual decision-maker. Examples based on \insertCiteSaaty2004;textualahpsurvey.
ahp.mat(df, atts, negconvert = FALSE, reciprocal = TRUE)
df |
a dataframe, each row corresponding to one decision-maker, with columns ordered according to |
atts |
a list of attributes in the correct order |
negconvert |
logical, whether to convert all positive values to
negative. In the pairwise comparison A_B, if -6 denotes A is more
important than B by 6 units, set |
reciprocal |
logical, whether to convert negative values (after |
A list of pairwise comparison matrices of each decision-maker.
Frankie Cho
Saaty2004ahpsurvey
data(city200)
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
ahp.mat(df = city200, atts = atts, negconvert = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.