| ahp.md | R Documentation |
Based on the matrix derived from ahp.error, replaces the top n number of inconsistent pairwise comparisons with a value calculated by from the maximum deviation method. For a full explication of the method see \insertCiteSaaty2003;textualahpsurvey. Replaces the old ahp.harker function before 0.4.2 but contains exactly the same functionality.
ahp.md(
ahpmat,
atts,
round = FALSE,
limit = FALSE,
iterations = 1,
stopcr = 0,
printiter = TRUE
)
ahpmat |
A list of pairwise comparison matrices of each decision maker generated by |
atts |
A list of attributes in the correct order |
round |
Rounds the imputation values of the matrix to the nearest integer if |
limit |
If set to |
iterations |
The number of comparisons with the highest inconsistency to be changed. For example, if |
stopcr |
The stopping Consistency Ratio, which was calculated by |
printiter |
Whether the number of iterations taken for each pairwise matrix is reported or not. If |
A list of matrices with values replaced with consistent values.
Frankie Cho
ahp.error ahp.cr
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
data(city200)
cityahp <- ahp.mat(city200, atts, negconvert = TRUE)
ahp.md(cityahp, atts)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.