ahp.pwerror: Finds the pairwise comparisons with the maximum amount of...

View source: R/ahp_pwerror.R

ahp.pwerrorR Documentation

Finds the pairwise comparisons with the maximum amount of inconsistency

Description

After constructing a list of matrices with \epsilon_{ij} = a_{ij}w_{j}/w_{i} (following ahp.error), this algorithm extracts the top n numbers of pairwise comparison matrices with the highest \epsilon_{ij} for each decision-maker.

Usage

ahp.pwerror(ahpmat, atts, npw = 3)

Arguments

ahpmat

A list of pairwise comparison matrices of each decision maker generated by ahp.mat.

atts

a list of attributes in the correct order

npw

Number of pairwise comparisons

Value

A list of matrices containing \epsilon_{ij} = a_{ij}w_{j}/w_{i} for each decision-maker, with elements from the lower triangle set as NA automatically (since it is essentially equal to the element in the upper triangle).

Author(s)

Frankie Cho

References

\insertRef

Saaty2004ahpsurvey

Examples


library(magrittr)

atts <- c('cult', 'fam', 'house', 'jobs', 'trans')

data(city200)

cityahp <- ahp.mat(city200, atts, negconvert = TRUE)
ahp.error(cityahp, atts)



ahpsurvey documentation built on July 16, 2026, 9:06 a.m.