city1: Dataframe of one decision-maker based on...

city1R Documentation

Dataframe of one decision-maker based on \insertCiteSaaty2004;textualahpsurvey

Description

A data.frame of one decision-maker with weights the same as \insertCiteSaaty2004;textualahpsurvey, with the pairwise comparisons of atts: c('cult', 'fam', 'house', 'jobs', 'trans'), about a choosing the best city to live in based on five attributes: Culture, Family, House, Jobs, and Transportation. Negative values in the data denote that the attribute on the left is more important than the right, thus if used with ahp.mat, negconvert must be set to TRUE.

Usage

data(city1)

Format

A data frame with 1 row and 10 variables, which are pairwise comparisons of atts.

\insertCite

Saaty2004;textualahpsurvey


ahpsurvey documentation built on July 16, 2026, 9:06 a.m.