| ahp.aggpref | R Documentation |
Compute and aggregate individual priority weights from pairwise comparison matrices
ahp.aggpref(ahpmat, atts, method = "geometric", aggmethod = method, qt = 0)
ahpmat |
A list of pairwise comparison matrices of each decision maker generated by |
atts |
a list of attributes in the correct order |
method |
if |
aggmethod |
how to aggregate the individual priorities. By default |
qt |
specifies the quantile which the top and bottom priority weights are trimmed. Used only if |
A data.frame of the aggregated priorities of all the decision-makers.
Frankie Cho
## Computes individual priorities with geometric mean and aggregates them
## with a trimmed arithmetic mean
library(magrittr)
data(city200)
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
cityahp <- ahp.mat(df = city200, atts = atts, negconvert = TRUE)
ahp.aggpref(cityahp, atts, method = 'geometric', aggmethod = 'tmean', qt = 0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.