| ahp.cr | R Documentation |
The ahp.cr function calculates the consistency ratio of each decision-maker, defined by the following equation:
CR = (\lambda-n)/((n-1)(RI))
Where \lambda is the maximum eigenvalue of the pairwise comparison matrix, n is the number of attributes, and RI is the random index. Following \insertCiteSaaty2007fuzzy;textualahpsurvey, the RI is a function of n and is the consistency ratio of randomly generated pairwise comparison matrices.
ahp.cr(ahpmat, atts, ri = NULL)
ahpmat |
A list of pairwise comparison matrices of each decision maker generated by |
atts |
a list of attributes in the correct order. The RI is asymptotic as it approaches n=15, thus it is set to be equal to 1.6 if the number of attributes exceeds 16. |
ri |
A user-supplied random index value, probably user generated using |
A list of consistency ratios of each decision-maker.
Frankie Cho
data(city200)
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
cityahp <- ahp.mat(df = city200, atts = atts, negconvert = TRUE)
ahp.cr(cityahp, atts)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.