ahp.indpref: Computes priority weights of individual decision-makers

View source: R/ahp_indpref.R

ahp.indprefR Documentation

Computes priority weights of individual decision-makers

Description

ahp.indpref computes the individual priorities of the decision-makers, and returns a data.frame containing the priority weights of the decision-makers.

Usage

ahp.indpref(ahpmat, atts, method = "geometric")

Arguments

ahpmat

A list of pairwise comparison matrices of each decision maker generated by ahp.mat.

atts

a list of attributes in the correct order

method

if method = "eigen", the individual priority weights are computed using the Dominant Eigenvalues method described in \insertCiteSaaty2003;textualahpsurvey. Otherwise, then the priorities are computed based on the averages of normalized values. Basically it normalizes the matrices so that all of the columns add up to 1, and then computes the averages of the row as the priority weights of each attribute. Three other modes of finding the averages are available: arithmetic: the arithmetic mean; geometric: the geometric mean (the default); rootmean: the square root of the sum of the squared value.

Value

A data.frame of the individual priorities of all the decision-makers.

Author(s)

Frankie Cho

References

\insertAllCited

Examples


data(city200)
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')

cityahp <- ahp.mat(df = city200, atts = atts, negconvert = TRUE) 
ahp.indpref(cityahp, atts, method = "eigen")


ahpsurvey documentation built on July 16, 2026, 9:06 a.m.