| ahp.indpref | R Documentation |
ahp.indpref computes the individual priorities of the decision-makers, and returns a data.frame containing the priority weights of the decision-makers.
ahp.indpref(ahpmat, atts, method = "geometric")
ahpmat |
A list of pairwise comparison matrices of each decision maker generated by |
atts |
a list of attributes in the correct order |
method |
if |
A data.frame of the individual priorities of all the decision-makers.
Frankie Cho
data(city200)
atts <- c('cult', 'fam', 'house', 'jobs', 'trans')
cityahp <- ahp.mat(df = city200, atts = atts, negconvert = TRUE)
ahp.indpref(cityahp, atts, method = "eigen")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.