Learn R Programming

ahpsurvey (version 0.4.3)

ahpsurvey-package: ahpsurvey: Analytic Hierarchy Process for Survey Data

Description

The Analytic Hierarchy Process is a versatile multi-criteria decision-making tool introduced by Saaty (1987) tools:::Rd_expr_doi("10.1016/0270-0255(87)90473-8") that allows decision-makers to weigh attributes and evaluate alternatives presented to them. This package provides a consistent methodology for researchers to reformat data and run analytic hierarchy process in R on data that are formatted using the survey data entry mode. It is optimized for performing the analytic hierarchy process with many decision-makers, and provides tools and options for researchers to aggregate individual preferences and test multiple options. It also allows researchers to quantify, visualize and correct for inconsistency in the decision-maker's comparisons.

Arguments

Author

Maintainer: Frankie Cho frankie.cho@monash.edu [copyright holder]

Authors:

See Also